==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebValuesChangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebValuesChangeDetailDescription } from "./WebValuesChangeDetailDescription";
/**
 * @hidden
 */
export let WebValuesChangeDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebValuesChangeDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebValuesChangeDetailDescriptionMetadata.a == null) {
                WebValuesChangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebValuesChangeDetailDescriptionMetadata.c(WebValuesChangeDetailDescriptionMetadata.a);
            }
            if (a.k(WebValuesChangeDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebValuesChangeDetailDescriptionMetadata.a);
            WebPivotValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ValuesChangeDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Values", "Array:WebPivotValueDescription:PivotValue");
        }
        static d(a) {
            WebValuesChangeDetailDescriptionMetadata.b(a);
            a.ac("WebValuesChangeDetail", () => new WebValuesChangeDetailDescription());
            a.ab("WebValuesChangeDetail", WebValuesChangeDetailDescriptionMetadata.a);
        }
    }
    WebValuesChangeDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebValuesChangeDetailDescriptionMetadata, 'WebValuesChangeDetailDescriptionMetadata');
    WebValuesChangeDetailDescriptionMetadata.a = null;
    return WebValuesChangeDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebValuesChangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebValuesChangeDetailDescription } from "./WebValuesChangeDetailDescription";
/**
 * @hidden
 */
export let WebValuesChangeDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebValuesChangeDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebValuesChangeDetailDescriptionMetadata.a == null) {
                WebValuesChangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebValuesChangeDetailDescriptionMetadata.c(WebValuesChangeDetailDescriptionMetadata.a);
            }
            if (a.k(WebValuesChangeDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebValuesChangeDetailDescriptionMetadata.a);
            WebPivotValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ValuesChangeDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Values", "Array:WebPivotValueDescription:PivotValue");
        }
        static d(a) {
            WebValuesChangeDetailDescriptionMetadata.b(a);
            a.ae("WebValuesChangeDetail", () => new WebValuesChangeDetailDescription());
            a.ad("WebValuesChangeDetail", WebValuesChangeDetailDescriptionMetadata.a);
        }
    }
    WebValuesChangeDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebValuesChangeDetailDescriptionMetadata, 'WebValuesChangeDetailDescriptionMetadata');
    WebValuesChangeDetailDescriptionMetadata.a = null;
    return WebValuesChangeDetailDescriptionMetadata;
})();
